@@ -1,11 +1,11 @@
 use strict;
 use warnings;
-package JSON::Schema::Modern; # git description: v0.569-9-g357987f3
+package JSON::Schema::Modern; # git description: v0.570-9-gb5589c0e
 # vim: set ts=8 sts=2 sw=2 tw=100 et :
 # ABSTRACT: Validate data against a schema
 # KEYWORDS: JSON Schema validator data validation structure specification
 
-our $VERSION = '0.570';
+our $VERSION = '0.571';
 
 use 5.020;  # for fc, unicode_strings features
 use Moo;
@@ -79,7 +79,9 @@ has max_traversal_depth => (
 has validate_formats => (
   is => 'ro',
   isa => Bool,
-  default => 0, # as specified by https://json-schema.org/draft/<version>/schema#/$vocabulary
+  lazy => 1,
+  # as specified by https://json-schema.org/draft/<version>/schema#/$vocabulary
+  default => sub { ($_[0]->specification_version//SPECIFICATION_VERSION_DEFAULT) eq 'draft7' ? 1 : 0 },
 );
 
 has validate_content_schemas => (
@@ -1028,7 +1030,7 @@ JSON::Schema::Modern - Validate data against a schema
 
 =head1 VERSION
 
-version 0.570
+version 0.571
 
 =head1 SYNOPSIS
 
@@ -1107,7 +1109,7 @@ other, or badly-written schemas that could be optimized. Defaults to 50.
 =head2 validate_formats
 
 When true, the C<format> keyword will be treated as an assertion, not merely an annotation. Defaults
-to false.
+to true when specification_version is draft7, and false otherwise.
 
 =head2 format_validations
 
